summaryrefslogtreecommitdiffstats
path: root/libkdenetwork/qgpgme/tests/dataprovidertest.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libkdenetwork/qgpgme/tests/dataprovidertest.cpp')
-rw-r--r--libkdenetwork/qgpgme/tests/dataprovidertest.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/libkdenetwork/qgpgme/tests/dataprovidertest.cpp b/libkdenetwork/qgpgme/tests/dataprovidertest.cpp
index 2493c586..675c85ea 100644
--- a/libkdenetwork/qgpgme/tests/dataprovidertest.cpp
+++ b/libkdenetwork/qgpgme/tests/dataprovidertest.cpp
@@ -1,20 +1,20 @@
/* tests/dataprovidertest.cpp
Copyright (C) 2004 Klarälvdalens Datakonsult AB
- This file is part of QGPGME's regression test suite.
+ This file is part of TQGPGME's regression test suite.
- QGPGME is free software; you can redistribute it and/or modify it
+ TQGPGME is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.
- QGPGME is distributed in the hope that it will be useful, but
+ TQGPGME is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
General Public License for more details.
You should have received a copy of the GNU General Public License
- along with QGPGME; if not, write to the Free Software Foundation,
+ along with TQGPGME; if not, write to the Free Software Foundation,
Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
// -*- c++ -*-
@@ -60,11 +60,11 @@ int main( int, char** ) {
{
//
- // QByteArrayDataProvider
+ // TQByteArrayDataProvider
//
// writing:
- QGpgME::QByteArrayDataProvider qba_dp;
+ QGpgME::TQByteArrayDataProvider qba_dp;
Data data( &qba_dp );
assertEqual( data.write( input, inputSize ), inputSize );
@@ -108,11 +108,11 @@ int main( int, char** ) {
{
//
// QByteArrayDataProvider with initial data:
//
TQByteArray ba;
ba.duplicate( input, inputSize );
- QGpgME::QByteArrayDataProvider qba_dp( ba );
+ QGpgME::TQByteArrayDataProvider qba_dp( ba );
Data data( &qba_dp );
assertEqual( data.seek( 0, SEEK_END ), inputSize );
@@ -108,11 +108,11 @@ int main( int, char** ) {
{
//
- // QByteArrayDataProvider with initial data:
+ // TQByteArrayDataProvider with initial data:
//
TQByteArray ba;